"""Common filenames and locations for elevation, meshes and outputs.
This script is the heart of all scripts in the folder
"""
#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

from os import sep, environ, getenv, getcwd
from os.path import expanduser
import sys
from time import localtime, strftime, gmtime
from anuga.utilities.polygon import read_polygon, plot_polygons, is_inside_polygon, number_mesh_triangles
from anuga.utilities.system_tools import get_user_name, get_host_name
from anuga.shallow_water.data_manager import urs2sts,create_sts_boundary
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon

#------------------------------------------------------------------------------
# Directory setup
#------------------------------------------------------------------------------
# Note: INUNDATIONHOME is the inundation directory, not the data directory.

home = getenv('INUNDATIONHOME') + sep +'data'+sep #Sandpit's parent diruser = get_user_name()
muxhome = getenv('MUXHOME')
user = get_user_name()
host = get_host_name()

# determines time for setting up output directories
time = strftime('%Y%m%d_%H%M%S',localtime()) 
gtime = strftime('%Y%m%d_%H%M%S',gmtime()) 
build_time = time+'_build'
run_time = time+'_run'

#------------------------------------------------------------------------------
# Initial Conditions
#------------------------------------------------------------------------------

# this section needs to be updated to reflect the modelled community.
# Note, the user needs to set up the directory system accordingly
state = 'western_australia'
scenario_name = 'carnarvon'
scenario = 'carnarvon_tsunami_scenario'

# Model specific parameters. One or all can be changed each time the
# run_scenario script is executed
tide = 1                #1.0
#event_number = 27255 # Java 9.3 worst case for Perth
#event_number = 68693 # Sumatra 9.2
event_number = 27283  # Java 9.3 original
alpha = 0.1             # smoothing parameter for mesh
friction=0.01           # manning's friction coefficient
starttime=0             
finaltime=80000         # final time for simulation

setup='final'  # Final can be replaced with trial or basic.
               # Either will result in a coarser mesh that will allow a
               # faster, but less accurate, simulation.

if setup =='trial':
    print'trial'
    res_factor=10
    time_thinning=48
    yieldstep=240
if setup =='basic': 
    print'basic'
    res_factor=4
    time_thinning=12
    yieldstep=120
if setup =='final': 
    print'final'
    res_factor=1
    time_thinning=4
    yieldstep=60

#------------------------------------------------------------------------------
# Output Filename
#------------------------------------------------------------------------------
# Important to distinguish each run - ensure str(user) is included!
# Note, the user is free to include as many parameters as desired
dir_comment='_'+setup+'_'+str(tide)+'_'+str(event_number)+'_'+ 'alpha' +str(alpha)+'_'+str(user)

#------------------------------------------------------------------------------
# Input Data
#------------------------------------------------------------------------------

# elevation data used in build_carnarvon.py
# onshore data: format ascii grid with accompanying projection file
onshore_name = 'dem_onshore' 
# bathymetry: format x,y,elevation (with title)
offshore_name = 'carnarvon_data.txt'
offshore_name1 = 'makeup.txt'
#grids made for aoi and aos as anuga interpretation was bad
topo_aoi = 'topo_20m_aoi'
topo_aos = 'topo_50m_aos'

# gauges - used in get_timeseries.py
gauge_name = 'MH_gauges_deep.csv' #'carnarvon.csv'
gauge_name2 = 'thinned_MGA50.csv'
#buildings - used in run_building_inundation.py
building = 'carnarvon_res'

# BOUNDING POLYGON - used in build_boundary.py and run_carnarvon.py respectively
# NOTE: when files are put together the points must be in sequence - for ease go clockwise!
# Check the run_carnarvon.py for boundary_tags
# thinned ordering file from Hazard Map: format is index,latitude,longitude (with title)
order_filename = 'thinned_boundary_ordering.csv'
#landward bounding points
landward = 'landward_bounding_polygon.csv'

#------------------------------------------------------------------------------
# Output Elevation Data
#------------------------------------------------------------------------------
# Output filename for elevation
# this is a combination of all the data (utilisied in build_boundary)
combined_name ='carnarvon_combined_elevation_quick'
combined_smaller_name = 'carnarvon_combined_elevation_smaller'

#------------------------------------------------------------------------------
# Directory Structure
#------------------------------------------------------------------------------
anuga_dir = home+state+sep+scenario+sep+'anuga'+sep
topographies_in_dir = home+state+sep+scenario+sep+'elevation_final'+sep+'points'+sep
topographies_dir = anuga_dir+'topographies'+sep
polygons_dir = anuga_dir+'polygons'+sep
tide_dir = anuga_dir+'tide_data'+sep
boundaries_dir = anuga_dir+'boundaries'+ sep 
output_dir = anuga_dir+'outputs'+sep
gauges_dir = anuga_dir+'gauges'+sep
meshes_dir = anuga_dir+'meshes'+sep

#------------------------------------------------------------------------------
# Location of input and output data
#------------------------------------------------------------------------------
# where the input data sits
onshore_in_dir_name = topographies_in_dir + onshore_name
offshore_in_dir_name = topographies_in_dir + offshore_name
offshore_in_dir_name1 = topographies_in_dir + offshore_name1
offshore_in_dir_aoi = topographies_in_dir + topo_aoi
offshore_in_dir_aos = topographies_in_dir + topo_aos

# where the output data sits
onshore_dir_name = topographies_dir + onshore_name
offshore_dir_name = topographies_dir + offshore_name
offshore_dir_name1 = topographies_dir + offshore_name1
offshore_dir_aoi = topographies_dir + topo_aoi
offshore_dir_aos = topographies_dir + topo_aos

# where the combined elevation file sits
combined_dir_name = topographies_dir + combined_name
combined_smaller_name_dir = topographies_dir + combined_smaller_name

# where the mesh sits (this is created during the run_carnarvon.py)
meshes_dir_name = meshes_dir + scenario_name+'.msh'

# where the boundary ordering files sit (this is used within build_boundary.py)
order_filename_dir = boundaries_dir + order_filename

# where the landward points of boundary extent sit (this is used within run_carnarvon.py)
landward_dir = boundaries_dir + landward

# where the event sts files sits (this is created during the build_boundary.py)
boundaries_dir_event = boundaries_dir + str(event_number) + sep
boundaries_dir_mux = muxhome

# where the directory of the output filename sits
output_build_time_dir = output_dir+build_time+dir_comment+sep   #used for build_carnarvon.py
output_run_time_dir = output_dir+run_time+dir_comment+sep       #used for run_carnarvon.py
output_run_time_dir_name = output_run_time_dir + scenario_name  #Used by post processing

#w here the directory of the gauges sit
gauges_dir_name = gauges_dir + gauge_name       #used for get_timeseries.py
gauges_dir_name2 = gauges_dir + gauge_name2     #used for get_timeseries.py
building_in_dir_name = gauges_dir + building + '.csv' 
#------------------------------------------------------------------------------
# Interior region definitions
#------------------------------------------------------------------------------

#Land, to set the initial stage/water to be offcoast only
#Land and Ocean to clip data
poly_mainland=read_polygon(polygons_dir +'land_initial_condition.csv')
poly_island1=read_polygon(polygons_dir +'land_initial_condition_bernier.csv')
poly_island2=read_polygon(polygons_dir +'land_initial_condition_dorne.csv')
poly_ocean=read_polygon(polygons_dir +'ocean_initial_condition.csv')
poly_aos_extract = read_polygon(polygons_dir+'extract_aos.csv')

# Initial bounding polygon for data clipping 
poly_all = read_polygon(polygons_dir+'poly_all.csv')
res_poly_all = 100000*res_factor

# Area of Interest 1 (carnarvon)
poly_aoi1 = read_polygon(polygons_dir+'Carnarvon5m.csv')
res_aoi1 = 500*res_factor

# Area of Significance 1 (carnarvon)
poly_aos1 = read_polygon(polygons_dir+'Carnarvon10m.csv')
res_aos1 = 1500*res_factor

# Shallow water 1
poly_sw1 = read_polygon(polygons_dir+'Carnarvon20m.csv')
res_sw1 = 25000*res_factor

# Shallow water 2
poly_sw2 = read_polygon(polygons_dir+'Island20m.csv')
res_sw2 = 50000*res_factor

# Combined all regions, must check that all are included!
interior_regions = [[poly_aoi1,res_aoi1],[poly_aos1,res_aos1]
                     ,[poly_sw1,res_sw1],[poly_sw2,res_sw2]]

    
trigs_min = number_mesh_triangles(interior_regions, poly_all, res_poly_all)
print 'min estimated number of triangles', trigs_min
   
#------------------------------------------------------------------------------
# Clipping regions for export to asc and regions for clipping data
# Final inundation maps should only be created in regions of the finest mesh
#------------------------------------------------------------------------------

# carnarvon CBD extract ascii grid
xminCBD = 763000
xmaxCBD = 775000
yminCBD = 7239000
ymaxCBD = 7251000
